package cn.rankin.resourceservice.controller;

import cn.rankin.common.utils.api.model.APICode;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.resource.ResourceSearchDTO;
import cn.rankin.data.api.resource.entity.Resource;
import cn.rankin.common.utils.constant.ResourceType;
import cn.rankin.resourceservice.service.ResourceService;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping(value = "resource")
public class ResourceController {

    @Autowired
    private ResourceService resourceService;

    @RequestMapping(value = "/list")
    public APIResult<Page<Resource>> search(ResourceSearchDTO resourceSearchDTO) {
        log.info(JSON.toJSONString(resourceSearchDTO));

        // 参数错误返回
        if (resourceSearchDTO == null || resourceSearchDTO.getType() == null) {
            return APIResult.error(APICode.PARAMETER_ERROR);
        }

        Integer type = resourceSearchDTO.getType();
        if (type.intValue() == ResourceType.IMG) {
            // 图片本地取
            Resource resource = new Resource();

            String code = resourceSearchDTO.getCode();
            if (!StringUtils.isEmpty(code)) {
                resource.setCode("%" + code.trim() + "%");
            }

            String name = resourceSearchDTO.getName();
            if (!StringUtils.isEmpty(name)) {
                resource.setName("%" + name.trim() + "%");
            }
            return resourceService.search(resource, resourceSearchDTO.getPageNo(), resourceSearchDTO.getPageSize());
        }else {
            // 其他去云平台
            if (resourceSearchDTO.getCode() != null) {
                return resourceService.findRemoteByCode(resourceSearchDTO.getCode());
            }else {
                return resourceService.findRemotePage(resourceSearchDTO);
            }
        }
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Resource> create(@RequestBody Resource resource) {
        if (StringUtils.isEmpty(resource.getCode()) || StringUtils.isEmpty(resource.getPath())) {
            return APIResult.error(APICode.PARAMETER_ERROR);
        }

        if (resourceService.exists(resource.getCode())) {
            return APIResult.error(APICode.ALREADY_EXISTS);
        }

        Resource result = resourceService.save(resource);

        return APIResult.ok(result);
    }

    @RequestMapping(value = "/batch", method = RequestMethod.GET)
    public APIResult<Map<String, Resource>> getBatch(@RequestParam("id") List<String> ids) {
        return resourceService.findMixByIds(ids);
    }
}
